from importlib import import_module


def run_etl_job(config, job_description):
    module = import_module(job_description['module_name'])
    Cls = getattr(module, job_description['class_name'])
    o = Cls(config, job_description)
    o.run(config.es, config.ES_URL)


def run_all_etls(config):
    for i in config.INDEXES:
        print(i)
        run_etl_job(config, i)





from distutils.core import setup

setup(
    name="etlelk",
    packages=['etlelk'],
    version="0.0.34",
    license="GNU Lesser General Public License v3.0",
    description="A small example package",
    author="Alex Lopes Pereira",
    author_email="alexlopespereira@gmail.com",
    url="https://github.com/alexlopespereira/etl_elk",
    download_url="https://github.com/alexlopespereira/etl_elk/archive/0.0.34.tar.gz",
    keywords=['elasticsearch', 'ETL'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    install_requires=[
        'bleach==3.1.1',
        'certifi>=2019.9.11',
        'cffi==1.14.0',
        'chardet==3.0.4',
        'cryptography==2.8',
        'docutils>=0.15',
        'elasticsearch==7.8.0',
        'idna>=2.8',
        'importlib-metadata==1.5.0',
        'jeepney==0.4.2',
        'keyring==21.1.0',
        'pkginfo==1.5.0.1',
        'pycparser==2.19',
        'Pygments==2.5.2',
        'readme-renderer==24.0',
        'requests>=2.22.0',
        'requests-toolbelt==0.9.1',
        'SecretStorage==3.1.2',
        'six>=1.12.0',
        'tqdm==4.43.0',
        'twine==3.1.1',
        'urllib3>=1.25.6',
        'webencodings==0.5.1',
        'zipp==3.0.0'
      ],
)




import os
from elasticsearch import Elasticsearch
from etlelk.settings_generic import body_settings_generic


class ConfigBase:
    KIBANA_SAVED_OBJECTS_PATH = os.environ.get('KIBANA_SAVED_OBJECTS_PATH') or "."
    KIBANA_HOST = os.environ.get('ES_HOST') or 'localhost'
    KIBANA_PORT = os.environ.get('ES_PORT') or '5601'
    ES_HOST = os.environ.get('ES_HOST') or 'localhost'
    ES_PORT = os.environ.get('ES_PORT') or '9200'
    ES_USER = os.environ.get('ES_USER') or 'admin'
    ES_PASSWORD = os.environ.get('ES_PASSWORD') or 'pass'
    ES_USE_SSL = os.environ.get('ES_USE_SSL') == "True"
    ES_SERVICOS_INDEX = os.environ.get('ES_SERVICOS_INDEX') or 'servicos'
    ES_SOURCECODE_INDEX = os.environ.get('ES_SOURCECODE_INDEX') or 'sourcecode'
    ES_TAGCLOUD_INDEX = os.environ.get('ES_TAGCLOUD_INDEX') or 'tagcloud'

    if ES_USE_SSL:
        ES_URL = "https://{0}:{1}".format(ES_HOST, ES_PORT)
        KIBANA_URL = "https://{0}:{1}".format(KIBANA_HOST, KIBANA_PORT)
    else:
        ES_URL = "http://{0}:{1}".format(ES_HOST, ES_PORT)
        KIBANA_URL = "http://{0}:{1}".format(KIBANA_HOST, KIBANA_PORT)
    
    
    INDEXES = []
    
    
    es = Elasticsearch(
        hosts=[{'host': ES_HOST, 'port': ES_PORT}],
        http_auth=(ES_USER, ES_PASSWORD),
        use_ssl=ES_USE_SSL,
        verify_certs=False
    )
    
    es = es
    
    # job_sourcecode = {"index": ES_SOURCECODE_INDEX, "settings": body_settings_sourcecode, "prefix": "SOURCECODE__",
    #                  "date_field": "date_modified", "description": "Source Code", "module_name": "ElkEtlPythonCode",
    #                  "class_name": "ElkEtlPythonCode", "src_path": "../data"}
    
    job_tagcloud = {"index": ES_TAGCLOUD_INDEX, "settings": body_settings_generic, "prefix": "TAGCLOUD__",
                     "description": "Tag Cloud", "module_name": "ElkEtlTagCloud",
                     "class_name": "ElkEtlTagCloud", "es": es}
    
    INDEXES = [job_tagcloud]
